@@ -9,4 +9,5 @@ class CommandResponse:
     status: string
     command_type: string
     error: string
-    content: object
\ No newline at end of file
+    content: string
+    formatted_content: string
\ No newline at end of file
